@@ -1,5 +1,8 @@
 import os
 
+def isLambda():
+    return os.getenv('_HANDLER', None) is not None
+
 def init(api):
     import bootstrap
 
